@@ -1,9 +1,9 @@
 /* Rename a file relative to open directories.
-   Copyright 2017-2020 Free Software Foundation, Inc.
+   Copyright 2017-2024 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 3 of the License, or
+   the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
@@ -19,6 +19,12 @@
 /* Get RENAME_* macros from <stdio.h> if present, otherwise supply
    the traditional Linux values.  */
 #include <stdio.h>
+
+#ifdef __cplusplus
+extern "C" {
+#endif
+
+
 #ifndef RENAME_NOREPLACE
 # define RENAME_NOREPLACE  (1 << 0)
 # define RENAME_EXCHANGE   (1 << 1)
@@ -26,3 +32,8 @@
 #endif
 
 extern int renameatu (int, char const *, int, char const *, unsigned int);
+
+
+#ifdef __cplusplus
+}
+#endif
