@@ -24,6 +24,8 @@
 #ifndef MANCONFIG_H
 #define MANCONFIG_H
 
+#include "config.h"
+
 /* STD_SECTIONS must contain all of your man hierarchy subdirectories. The
    order is important. Manual pages will be displayed in this order. Ie
    if "1" comes before "2", then a kill(1) will be displayed in preference to
@@ -138,13 +140,13 @@
 #define UNLIKELY(cond) __builtin_expect ((cond), 0)
 
 /* GNU gettext needs to know when the locale changes. This macro tells it. */
-#ifdef ENABLE_NLS
+#ifdef HAVE_NL_MSG_CAT_CNTR
 extern int _nl_msg_cat_cntr;
 #  define locale_changed()                                                    \
 	  do {                                                                \
 		  ++_nl_msg_cat_cntr;                                         \
 	  } while (0)
-#else /* !ENABLE_NLS */
+#else /* !HAVE_NL_MSG_CAT_CNTR */
 #  define locale_changed()
 #endif /* ENABLE_NLS */
 
