@@ -25,12 +25,16 @@
 #include "mydbm.h"
 
 /* check_mandirs.c */
+extern bool opt_test;
+extern int pages;
+extern bool force_rescan;
+
 extern void test_manfile (MYDBM_FILE dbf, const char *file, const char *path);
 extern void chown_if_possible (const char *path);
-extern int create_db (MYDBM_FILE dbf,
-		      const char *manpath, const char *catpath);
-extern int update_db (MYDBM_FILE dbf,
-		      const char *manpath, const char *catpath);
+extern int create_db (MYDBM_FILE dbf, const char *manpath,
+                      const char *catpath);
+extern int update_db (MYDBM_FILE dbf, const char *manpath,
+                      const char *catpath);
 extern void purge_pointers (MYDBM_FILE dbf, const char *name);
-extern int purge_missing (MYDBM_FILE dbf,
-			  const char *manpath, const char *catpath);
+extern int purge_missing (MYDBM_FILE dbf, const char *manpath,
+                          const char *catpath);
