@@ -46,7 +46,6 @@
 
 #include "globbing.h"
 
-extern const char *extension;
 static bool match_case = false;
 static bool regex_opt = false;
 static bool wildcard = false;
@@ -56,18 +55,19 @@ const char *argp_program_version = "globbing " PACKAGE_VERSION;
 const char *argp_program_bug_address = PACKAGE_BUGREPORT;
 error_t argp_err_exit_status = FAIL;
 
-static const char args_doc[] = N_("PATH SECTION NAME");
+static const char args_doc[] = N_ ("PATH SECTION NAME");
 
 static struct argp_option options[] = {
-	{ "debug",		'd',	0,			0,	N_("emit debugging messages") },
-	{ "extension",		'e',	N_("EXTENSION"),	0,	N_("limit search to extension type EXTENSION") },
-	{ "ignore-case",	'i',	0,			0,	N_("look for pages case-insensitively (default)") },
-	{ "match-case",		'I',	0,			0,	N_("look for pages case-sensitively") },
-	{ "regex",		'r',	0,			0,	N_("interpret page name as a regex") },
-	{ "wildcard",		'w',	0,			0,	N_("the page name contains wildcards") },
-	{ 0, 'h', 0, OPTION_HIDDEN, 0 }, /* compatibility for --help */
-	{ 0 }
-};
+        OPT ("debug", 'd', 0, N_ ("emit debugging messages")),
+        OPT ("extension", 'e', N_ ("EXTENSION"),
+             N_ ("limit search to extension type EXTENSION")),
+        OPT ("ignore-case", 'i', 0,
+             N_ ("look for pages case-insensitively (default)")),
+        OPT ("match-case", 'I', 0, N_ ("look for pages case-sensitively")),
+        OPT ("regex", 'r', 0, N_ ("interpret page name as a regex")),
+        OPT ("wildcard", 'w', 0, N_ ("the page name contains wildcards")),
+        OPT_HELP_COMPAT,
+        {0}};
 
 static error_t parse_opt (int key, char *arg, struct argp_state *state)
 {
@@ -92,7 +92,7 @@ static error_t parse_opt (int key, char *arg, struct argp_state *state)
 			return 0;
 		case 'h':
 			argp_state_help (state, state->out_stream,
-					 ARGP_HELP_STD_HELP);
+			                 ARGP_HELP_STD_HELP);
 			break;
 		case ARGP_KEY_ARGS:
 			if (state->argc - state->next != 3)
@@ -106,7 +106,7 @@ static error_t parse_opt (int key, char *arg, struct argp_state *state)
 	return ARGP_ERR_UNKNOWN;
 }
 
-static struct argp argp = { options, parse_opt, args_doc };
+static struct argp argp = {options, parse_opt, args_doc};
 
 int main (int argc, char **argv)
 {
@@ -126,10 +126,10 @@ int main (int argc, char **argv)
 		const char *file;
 
 		files = look_for_file (remaining_args[0], remaining_args[1],
-				       remaining_args[2], i,
-				       (match_case ? LFF_MATCHCASE : 0) |
-				       (regex_opt ? LFF_REGEX : 0) |
-				       (wildcard ? LFF_WILDCARD : 0));
+		                       remaining_args[2], (bool) i,
+		                       (match_case ? LFF_MATCHCASE : 0) |
+		                               (regex_opt ? LFF_REGEX : 0) |
+		                               (wildcard ? LFF_WILDCARD : 0));
 		GL_LIST_FOREACH (files, file)
 			printf ("%s\n", file);
 		gl_list_free (files);
